@@ -18,79 +18,103 @@
 #' adding a `ggplot` object or `plot_instr`, these arguments will be used
 #' by png function.
 #' @examples
+#' # this name will be used to print the file
+#' # change it to "youfile.pptx" to write the pptx
+#' # file in your working directory.
 #' fileout <- tempfile(fileext = ".pptx")
-#' doc <- read_pptx()
-#' doc <- add_slide(doc, layout = "Two Content",
-#'   master = "Office Theme")
-#' doc <- ph_with(x = doc, value = c("Un titre", "Deux titre"),
-#'                location = ph_location_left() )
-#' doc <- ph_with(x = doc, value = iris[1:4, 3:5],
-#'                location = ph_location_right() )
 #'
 #'
+#' doc_1 <- read_pptx()
+#' sz <- slide_size(doc_1)
+#' # add text and a table ----
+#' doc_1 <- add_slide(doc_1, layout = "Two Content", master = "Office Theme")
+#' doc_1 <- ph_with(x = doc_1, value = c("Table cars"),
+#'    location = ph_location_type(type = "title") )
+#' doc_1 <- ph_with(x = doc_1, value = names(cars),
+#'    location = ph_location_left() )
+#' doc_1 <- ph_with(x = doc_1, value = cars,
+#'    location = ph_location_right() )
+#'
+#' # add a base plot ----
 #' anyplot <- plot_instr(code = {
-#'   barplot(1:5, col = 2:6)
+#'   col <- c("#440154FF", "#443A83FF", "#31688EFF",
+#'            "#21908CFF", "#35B779FF", "#8FD744FF", "#FDE725FF")
+#'   barplot(1:7, col = col, yaxt="n")
 #' })
 #'
-#' doc <- add_slide(doc)
-#' doc <- ph_with(
-#'   doc, anyplot,
+#' doc_1 <- add_slide(doc_1)
+#' doc_1 <- ph_with( doc_1, anyplot,
 #'   location = ph_location_fullsize(),
-#'   bg = "#00000066", pointsize = 12)
+#'   bg = "#006699")
 #'
+#' # add a ggplot2 plot ----
 #' if( require("ggplot2") ){
-#'   doc <- add_slide(doc)
+#'   doc_1 <- add_slide(doc_1)
 #'   gg_plot <- ggplot(data = iris ) +
 #'     geom_point(mapping = aes(Sepal.Length, Petal.Length),
-#'       size = 3) +
+#'                size = 3) +
 #'     theme_minimal()
-#'   doc <- ph_with(x = doc, value = gg_plot,
-#'                  location = ph_location_fullsize(),
-#'                  bg = "transparent" )
-#'   doc <- ph_with(x = doc, value = "graphic title",
-#'                location = ph_location_type(type="title") )
+#'   doc_1 <- ph_with(x = doc_1, value = gg_plot,
+#'                    location = ph_location_type(type = "body"),
+#'                    bg = "transparent" )
+#'   doc_1 <- ph_with(x = doc_1, value = "graphic title",
+#'                    location = ph_location_type(type="title") )
 #' }
 #'
-#' doc <- add_slide(doc, layout = "Title and Content",
-#'   master = "Office Theme")
-#' img.file <- file.path( R.home("doc"), "html", "logo.jpg" )
-#' doc <- ph_with(x = doc, external_img(img.file, 100/72, 76/72),
-#'                location = ph_location_right(), use_loc_size = FALSE )
+#' # add a external images ----
+#' doc_1 <- add_slide(doc_1, layout = "Title and Content",
+#'                    master = "Office Theme")
+#' doc_1 <- ph_with(x = doc_1, value = empty_content(),
+#'   location = ph_location(left = 0, top = 0,
+#'     width = sz$width, height = sz$height, bg = "black") )
 #'
 #' svg_file <- file.path(R.home(component = "doc"), "html/Rlogo.svg")
 #' if( require("rsvg") ){
-#'   doc <- ph_with(x = doc, external_img(svg_file),
-#'     location = ph_location_left(),
-#'     use_loc_size = TRUE )
+#'   doc_1 <- ph_with(x = doc_1, value = "External images",
+#'                    location = ph_location_type(type = "title") )
+#'   doc_1 <- ph_with(x = doc_1, external_img(svg_file, 100/72, 76/72),
+#'                    location = ph_location_right(), use_loc_size = FALSE )
+#'   doc_1 <- ph_with(x = doc_1, external_img(svg_file),
+#'                    location = ph_location_left(),
+#'                    use_loc_size = TRUE )
 #' }
-#' # block list ------
+#'
+#' # add a block_list ----
+#' dummy_text <- readLines(system.file(package = "officer",
+#'   "doc_examples/text.txt"))
+#' fp_1 <- fp_text(bold = TRUE, color = "pink", font.size = 0)
+#' fp_2 <- fp_text(bold = TRUE, font.size = 0)
+#' fp_3 <- fp_text(italic = TRUE, color="red", font.size = 0)
 #' bl <- block_list(
-#'   fpar(ftext("hello world", shortcuts$fp_bold(color = "pink"))),
+#'   fpar(ftext("hello world", fp_1)),
 #'   fpar(
-#'     ftext("hello", shortcuts$fp_bold()),
-#'     ftext("hello", shortcuts$fp_italic(color="red"))
-#'   ))
-#' doc <- add_slide(doc)
-#' doc <- ph_with(x = doc, value = bl,
-#'                location = ph_location_type(type="body") )
+#'     ftext("hello", fp_2),
+#'     ftext("hello", fp_3)
+#'   ),
+#'   dummy_text
+#' )
+#' doc_1 <- add_slide(doc_1)
+#' doc_1 <- ph_with(x = doc_1, value = bl,
+#'    location = ph_location_type(type="body") )
+#'
 #'
 #' # fpar ------
-#' hw <- fpar(ftext("hello world", shortcuts$fp_bold(color = "pink")))
-#' doc <- add_slide(doc)
-#' doc <- ph_with(x = doc, value = hw,
-#'                location = ph_location_type(type="body") )
-
-
+#' hw <- fpar(ftext("hello world",
+#'   fp_text(bold = TRUE, font.family = "Bradley Hand",
+#'     font.size = 150, color = "#F5595B")))
+#' doc_1 <- add_slide(doc_1)
+#' doc_1 <- ph_with(x = doc_1, value = hw,
+#'                  location = ph_location_type(type="body") )
 #' # unordered_list ----
 #' ul <- unordered_list(
 #'   level_list = c(1, 2, 2, 3, 3, 1),
 #'   str_list = c("Level1", "Level2", "Level2", "Level3", "Level3", "Level1"),
 #'   style = fp_text(color = "red", font.size = 0) )
-#' doc <- add_slide(doc)
-#' doc <- ph_with(x = doc, value = ul,
-#'                location = ph_location_fullsize() )
+#' doc_1 <- add_slide(doc_1)
+#' doc_1 <- ph_with(x = doc_1, value = ul,
+#'                  location = ph_location_type() )
 #'
-#' print(doc, target = fileout )
+#' print(doc_1, target = fileout )
 #' @seealso [ph_location_type], [ph_location], [ph_location_label],
 #' [ph_location_left], [ph_location_right], [ph_location_fullsize],
 #' [ph_location_template]
@@ -240,20 +264,24 @@ ph_with.unordered_list <- function(x, value, location, ...){
 
 #' @export
 #' @param header display header if TRUE
-#' @param first_row,last_row,first_column,last_column logical for PowerPoint table options
-#' @describeIn ph_with add a data.frame to a new shape on the current slide. Use
-#' package \code{flextable} instead for more advanced formattings.
+#' @param tcf conditional formatting settings defined by [table_conditional_formatting()]
+#' @describeIn ph_with add a data.frame to a new shape on the current slide with
+#' function [block_table()]. Use package \code{flextable} instead for more
+#' advanced formattings.
 ph_with.data.frame <- function(x, value, location, header = TRUE,
-                               first_row = TRUE, first_column = FALSE,
-                               last_row = FALSE, last_column = FALSE, ...){
+                               tcf = table_conditional_formatting(),
+                               ...){
   location <- fortify_location(location, doc = x)
 
   slide <- x$slide$get_slide(x$cursor)
   style_id <- x$table_styles$def[1]
 
-  bt <- block_table(x = value, style = style_id, header = header, first_row = first_row,
-              first_column = first_column, last_row = last_row,
-              last_column = last_column)
+  pt <- prop_table(
+    style = style_id, layout = table_layout(),
+    width = table_width(),
+    tcf = tcf)
+
+  bt <- block_table(x = value, header = header, properties = pt)
 
   xml_elt <- to_pml(
     bt, left = location$left, top = location$top,
